function DataSourceHolder(ZHPromise, restEngine, ZhLogger) {

	this.dataSources = [];
	var self = this;

	this.isLoaded = function(name) {
		return !!this.dataSources[this.clearName(name)];
	};

	this.clearName = function(name) {
		return name.replace('/', '');
	};
	
	this.realName = function dataSourceRealName(name) {
		return name.split('/').pop();
	};

	this.setDataSource = function(name, dataSource) {
		this.dataSources[this.clearName(name)] = dataSource;
	};

	this.getDataSourceLazy = function(name) {
		var clearedName = this.clearName(name);
		return this.dataSources[clearedName];
	};

	function initDataSourceMeta(name, data, realName) {
		var dataSourceVo = DataSourceVo.factory(name, data, realName);
		if (dataSourceVo.keyPath) {
			dataSourceVo.localKey = Util.parseToArray(dataSourceVo.keyPath);
		} else {
			dataSourceVo.localKey = Util.parseToArray(dataSourceVo.localKey);
		}
		dataSourceVo.name = name;
		self.dataSources[name] = data;
	}

	this.getDataSource = function(name) {
		var clearedName = this.clearName(name);
		if (!this.isLoaded(clearedName)) {
			var filename = clearedName + ".json";
			return restEngine.requestMetaData(Util.getRightPath(filename, "json/datasources/"), {}, function(data) {
				var dataSourceRealName = self.realName(Util.getPackageUrl(clearedName));
				initDataSourceMeta(clearedName, data, dataSourceRealName);
			}).then(null, function() {
				initDataSourceMeta(clearedName, {});
				ZhLogger.error("Datasource not found: " + name + ", at " + filename);
			});
		} else {
			return ZHPromise.when(this.getDataSourceLazy(clearedName));
		}
	};
}